@@ -22,8 +22,9 @@
 #define PRINT_KCM_H
 
 #include <KCModule>
-#include <QIcon>
+#include <KPluginFactory>
 
+#include <QIcon>
 #include <QAction>
 
 #include <KCupsServer.h>
@@ -50,16 +51,16 @@ private slots:
     void showInfo(const QIcon &icon, const QString &title, const QString &comment, bool showAddPrinter, bool showToolButtons);
 
     void getServerSettings();
-    void getServerSettingsFinished();
-    void updateServerFinished();
+    void getServerSettingsFinished(KCupsRequest *request);
+    void updateServerFinished(KCupsRequest *request);
     void systemPreferencesTriggered();
 
 private:
     Ui::PrintKCM *ui;
     PrinterModel *m_model;
-    int m_lastError;
+    int m_lastError = -1; // Force the error to run on the first time
 
-    KCupsRequest *m_serverRequest;
+    KCupsRequest *m_serverRequest = nullptr;
     QAction *m_showSharedPrinters;
     QAction *m_shareConnectedPrinters;
     QAction *m_allowPrintringFromInternet;
@@ -67,4 +68,6 @@ private:
     QAction *m_allowUsersCancelAnyJob;
 };
 
+K_PLUGIN_FACTORY(PrintKCMFactory, registerPlugin<PrintKCM>();)
+
 #endif
